// SPDX-FileCopyrightText: 2024 Petros Koutsolampros
//
// SPDX-License-Identifier: GPL-3.0-only

#pragma once

#include "salalib/shapemap.h"
#include "salalib/shapegraph.h"
#include "salalib/alllinemap.h"
#include "salalib/pointmap.h"
